==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-CN" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation>逆向工程</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>近似​​平面...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>近似​​一平面</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation>逆向工程</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation>近似 B样条曲面...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation>近似 B样条曲面</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation>近似贝塞尔曲面</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation>近似曲面...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>近似B样条曲面</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation>逆向工程</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation>泊松...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation>泊松曲面重构</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation>逆向工程</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation>结构化的点云</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation>结构点云的三角剖分</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation>拟合贝塞尔曲面</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation>拟合 B样条曲面</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation>u-方向</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation>度</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation>控制点</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation>v-方向</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation>设置</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation>迭代</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation>尺寸因数</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>平滑</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation>总重量</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation>渐变长度</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation>弯曲能量</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation>曲率变化</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation>用户定义的 u/v 方向</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>选择错误</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>请选择单个放置对象以获取本地方向。</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation>输入错误</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation>泊松</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation>参数</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation>八分树深度</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation>规划求解除法</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation>每个节点的示例</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation>输入错误</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>选择错误</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation>请选择单一的点云。</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation>视图三角化失败</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>逆向工程</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-CN" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation>逆向工程</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>近似​​平面...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>近似​​一平面</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation>逆向工程</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation>近似 B样条曲面...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation>近似 B样条曲面</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation>近似贝塞尔曲面</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation>近似曲面...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>近似B样条曲面</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation>逆向工程</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation>泊松...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation>泊松曲面重构</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation>逆向工程</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation>结构化的点云</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation>结构点云的三角剖分</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation>拟合贝塞尔曲面</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation>拟合 B样条曲面</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation>u-方向</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation>度</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation>控制点</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation>v-方向</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation>设置</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation>迭代次数</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation>尺寸系数</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>平滑</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation>总重量</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation>渐变长度</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation>弯曲能量</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation>曲率变化</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation>用户定义的 u/v 方向</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>选择错误</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>请选择单个放置对象以获取本地方向。</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation>输入错误</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation>泊松</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation>参数</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation>八分树深度</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation>规划求解除法</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation>每个节点的示例</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation>输入错误</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>选择错误</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation>请选择单一的点云。</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation>视图三角化失败</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>逆向工程</translation>
    </message>
  </context>
</TS>
